# Pydis
===========================================
Make your Discord Bot quickly and easily on Python!

## Features
- Modern code! (async await)
- Don't worrie by Intents! (Intents are not needed here)
- Easy to use!
- Easy to extend!
- Easy to understand!
- Easy to maintain!
- Lightweight!
- Fast!
- Open source!
- Python 3.6+
- Discord.py library fork

## Installation

```bash
pip install pydis-discord=1.0.0
```

## Usage

Alert: There is a wiki on Github

### Making a Ping Pong bot!
```python
from pydis import GatewayDiscordApp

bot = GatewayDiscordApp()

@bot.event
async def on_ready():
    print('Ready!')

@bot.event
async def on_message(message):
    if message.content == 'ping':
        await message.channel.send('Pong! :ping_pong:')

bot.run()
```

## License
MIT License

## TODO
- Create slash commands easier!
- More wiki
- Examples
